==> haskell-input-parsers-0.3.0.2-56-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-input-parsers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 input-parsers
version:              0.3.0.2
visibility:           public
id:                   input-parsers-0.3.0.2-Jd39pp6tNZL5rUQ1VMfhMp
key:                  input-parsers-0.3.0.2-Jd39pp6tNZL5rUQ1VMfhMp
license:              BSD-3-Clause
copyright:            (c) 2020 Mario Blažević
maintainer:           blamario@protonmail.com
author:               Mario Blažević
synopsis:
    Extension of the parsers library with more capability and efficiency

description:
    Extended version of the parsers library, with the additional classes providing more
    capable and efficient methods.

category:             Parsing
abi:                  f15293901d7ece6ac6a610d406749ea5
exposed:              True
exposed-modules:
    Text.Parser.Deterministic Text.Parser.Input
    Text.Parser.Input.Position Text.Parser.Wrapper

hidden-modules:       Text.Parser.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/input-parsers-0.3.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/input-parsers-0.3.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/input-parsers-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-input-parsers
hs-libraries:         HSinput-parsers-0.3.0.2-Jd39pp6tNZL5rUQ1VMfhMp
depends:
    attoparsec-0.14.4-GPSHKdrOxNAHtLNPx9PvVS base-4.17.2.1
    binary-0.8.9.1 bytestring-0.11.5.3
    monoid-subclasses-1.2.6-5n1REWH5m8S1EfVe1Yx85u parsec-3.1.16.1
    parsers-0.12.12-DSXrb12WW9pAlDntPLXdEB text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-input-parsers/html/input-parsers.haddock

haddock-html:         /usr/share/doc/haskell-input-parsers/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-input-parsers-0.3.0.2-57-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-input-parsers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 input-parsers
version:              0.3.0.2
visibility:           public
id:                   input-parsers-0.3.0.2-LwFmjDJoAFVGUpVC5PEItv
key:                  input-parsers-0.3.0.2-LwFmjDJoAFVGUpVC5PEItv
license:              BSD-3-Clause
copyright:            (c) 2020 Mario Blažević
maintainer:           blamario@protonmail.com
author:               Mario Blažević
synopsis:
    Extension of the parsers library with more capability and efficiency

description:
    Extended version of the parsers library, with the additional classes providing more
    capable and efficient methods.

category:             Parsing
abi:                  cb16204ca7c799b98cd62033b0f8408d
exposed:              True
exposed-modules:
    Text.Parser.Deterministic Text.Parser.Input
    Text.Parser.Input.Position Text.Parser.Wrapper

hidden-modules:       Text.Parser.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/input-parsers-0.3.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/input-parsers-0.3.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/input-parsers-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-input-parsers
hs-libraries:         HSinput-parsers-0.3.0.2-LwFmjDJoAFVGUpVC5PEItv
depends:
    attoparsec-0.14.4-21g0xvIiXNtBpdLdrKPYdv base-4.17.2.1
    binary-0.8.9.1 bytestring-0.11.5.3
    monoid-subclasses-1.2.6-IlXJkYMqn6oE7pT7lvhP2L parsec-3.1.16.1
    parsers-0.12.12-5OyYB0LWB7z3XJTkbw3KeS text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-input-parsers/html/input-parsers.haddock

haddock-html:         /usr/share/doc/haskell-input-parsers/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
